==> apidotjs-0.4.1.tgz: package/webpack.config.js <==
var config  = require('./gulp/config.js');
var webpack = require('webpack');


module.exports = {
     name: 'node_config',
     target: 'node',
     debug: true,
     context: __dirname + '/' + config.js.src,
     entry: {
        'api' : __dirname + '/' + config.js.main,
        'api.min' : __dirname + '/' + config.js.main
     },
     output: {
         path: __dirname + config.js.dest,
         filename: '[name].js',
         library: config.project_name,
         libraryTarget: 'commonjs'
     },
     module: {
         loaders: [
            {
                test:  /\.json$/, loader: 'json-loader',
             }, {
                test: /\.js$/,
                exclude: /(node_modules|bower_components)/,
                loader: 'babel-loader'
             }
         ]
     },
     resolve: {
        extensions: ['', '.webpack.js', '.web.js', '.js']
    },
    plugins: [
        new webpack.DefinePlugin({
            'process.env': {
                // This has effect on the react lib size
                'NODE_ENV': JSON.stringify('production'),
		'API_URL': 'http://127.0.0.1:8000',
            }
        }),	
        new webpack.optimize.OccurenceOrderPlugin(),
        new webpack.optimize.UglifyJsPlugin({
            comments: false,
            include: /\.min\.js$/,
            mangle: false,
            minimize: true,
            compress: {
                unused: true,
                dead_code: true,
                warnings: false,
                drop_debugger: true,
                drop_console: true
            }
        })
    ]
 }

==> apidotjs-0.4.3.tgz: package/webpack.config.js <==
var config  = require('./gulp/config.js');
var webpack = require('webpack');
var WebpackBundleSizeAnalyzerPlugin = require('webpack-bundle-size-analyzer').WebpackBundleSizeAnalyzerPlugin;



module.exports = {
     name: 'node_config',
     target: 'node',
	 devtool: 'source-map',
     context: __dirname + '/' + config.js.src,
     entry: {
        'api' : __dirname + '/' + config.js.main,
        'api.min' : __dirname + '/' + config.js.main
     },
     output: {
         path: __dirname + config.js.dest,
         filename: '[name].js',
         library: config.project_name,
         libraryTarget: 'commonjs'
     },
     module: {
         loaders: [
            {
                test:  /\.json$/, loader: 'json-loader',
             }, {
                test: /\.js$/,
                exclude: /(node_modules|bower_components)/,
                loader: 'babel-loader'
             }
         ]
     },
     resolve: {
        extensions: ['','.js', '.webpack.js']
    },
    plugins: [
		new WebpackBundleSizeAnalyzerPlugin('./reports/plain-report.txt'),
        new webpack.DefinePlugin({
            'process.env': {
                // This has effect on the react lib size
                'NODE_ENV': JSON.stringify('production')
            }
        }),
        new webpack.optimize.UglifyJsPlugin({
            comments: false,
            include: /\.min\.js$/,
            mangle: {
				except: ['API', 'Base']
			},
            minimize: true,
            compress: {
                unused: true,
                dead_code: true,
                warnings: false,
                drop_debugger: true,
                drop_console: true,
				screw_ie8: true
            }
        })
    ]
 }
